# PrivateStreetNoticeResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**private_street_reference_number** | **str** |  | 
**proposed_start_date** | **datetime** |  | 
**proposed_end_date** | **datetime** |  | 
**private_street_status** | [**PrivateStreetStatusResponse**](PrivateStreetStatusResponse.md) |  | 
**private_street_status_string** | **str** |  | 
**work_reference_number** | **str** |  | 
**promoter_organisation** | **str** |  | 
**promoter_swa_code** | **str** |  | 
**secondary_contact** | **str** |  | 
**secondary_contact_number** | **str** |  | 
**secondary_contact_email** | **str** |  | [optional] 
**proposed_start_time** | **datetime** |  | [optional] 
**proposed_end_time** | **datetime** |  | [optional] 
**calendar_day_duration** | **float** |  | 
**working_day_duration** | **float** |  | 
**description_of_work** | **str** |  | 
**excavation** | **bool** |  | 
**project_reference_number** | **str** |  | [optional] 
**street_name** | **str** |  | 
**town** | **str** |  | [optional] 
**area_name** | **str** |  | [optional] 
**usrn** | **str** |  | 
**highway_authority** | **str** |  | 
**highway_authority_swa_code** | **str** |  | 
**works_location_description** | **str** |  | 
**works_coordinates** | **object** |  | 
**date_created** | **datetime** |  | 
**date_modified** | **datetime** |  | 
**traffic_management_type** | [**TrafficManagementTypeResponse**](TrafficManagementTypeResponse.md) |  | 
**traffic_management_type_string** | **str** |  | 
**location_types** | [**list[LocationTypeResponse]**](LocationTypeResponse.md) |  | 
**location_types_string** | **list[str]** |  | 
**files** | [**list[FileSummaryResponse]**](FileSummaryResponse.md) |  | [optional] 
**workstream_prefix** | **str** |  | 
**close_footway** | [**CloseFootwayResponse**](CloseFootwayResponse.md) |  | 
**close_footway_string** | **str** |  | 
**work_status** | [**WorkStatusResponse**](WorkStatusResponse.md) |  | 
**work_status_string** | **str** |  | 
**additional_contact** | **str** |  | [optional] 
**additional_contact_number** | **str** |  | [optional] 
**additional_contact_email** | **str** |  | [optional] 
**emergency_contact_name** | **str** |  | [optional] 
**emergency_contact_number** | **str** |  | [optional] 
**close_footpath** | [**CloseFootpathResponse**](CloseFootpathResponse.md) |  | 
**close_footpath_string** | **str** |  | 
**street_line** | **object** |  | [optional] 
**road_category** | **float** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

